@@ -102,9 +102,16 @@ public:
     void setStreamUuid(QString uuid);
 #endif
 
+#if (PHONON_VERSION >= PHONON_VERSION_CHECK(4, 8, 50))
+    void setMuted(bool mute);
+#endif
+
+    virtual void setCategory(Phonon::Category category);
+
 signals:
     void volumeChanged(qreal volume);
     void audioDeviceFailed();
+    void mutedChanged(bool mute);
 
 private slots:
     /**
@@ -112,6 +119,9 @@ private slots:
      */
     void applyVolume();
 
+    void onMutedChanged(bool mute);
+    void onVolumeChanged(float volume);
+
 private:
     /**
      * We can only really set the output device once we have a libvlc_media_player, which comes
@@ -120,8 +130,12 @@ private:
     void setOutputDeviceImplementation();
 
     qreal m_volume;
+    // Set after first setVolume to indicate volume was set manually.
+    bool m_explicitVolume;
+    bool m_muted;
     AudioOutputDevice m_device;
     QString m_streamUuid;
+    Category m_category;
 };
 
 } // namespace VLC
